package esac.archive.pla.common.constants;

/**
 * Utility class to store String values shared by Web and Data Distribution applications.
 * 
 * @author Maria Henar Sarmiento Carrion Copyright (c) 2012 - European Space Agency
 * 
 */
public class PlaRetrievalConstants {

    /**
     * Default constructor, it should not be called.
     */
    protected PlaRetrievalConstants() {
        // prevents calls from subclass
        throw new UnsupportedOperationException();
    }

    // //////////////////////////////////////////////////////////////////////////////
    // / Generic Retrieval constants (should be in ABSI?) ///
    // //////////////////////////////////////////////////////////////////////////////

    /** Expected Retrieval element keys */
    public static final String RETRIEVAL_TYPE_KEY = "RetrievalType";
    public static final String PRODUCT_TYPE_KEY = "ProductType";

    /** Product/Postcard Retrieval types. */
    public static final String PRODUCT_RETRIEVAL_TYPE = "PRODUCT";
    public static final String POSTCARD_RETRIEVAL_TYPE = "POSTCARD";

    /** Several retrieval element keys. */
    public static final String REP_MAP_QB_KEY = "REP_MAP_QUERY_BEAN";
    public static final String EFFECTIVE_BEAMS_QB_KEY = "EFFECTIVE_BEAMS_QUERY_BEAN";
    public static final String TOI_CUTTING_QB_KEY = "TOI_CUTTING_QUERY_BEAN";
    public static final String MAP_TYPE_KEY = "MAP.TYPE";

    public static final String ROI_LON = "ROI_LON";
    public static final String ROI_LAT = "ROI_LAT";
    public static final String ROI_WIDTH = "ROI_WIDTH";
    public static final String RESOLUTION = "RESOLUTION";
    public static final String ROTATION = "ROTATION";
    public static final String USE_DRIZZLING = "USE_DRIZZLING";
    // Map extension index
    public static final String MAP_EXT_IDX = "MAP_EXT_IDX";
    // Column extension name
    public static final String MAP_EXT_COL = "MAP_EXT_COL";
    public static final String FREQUENCY = "FREQUENCY";
    public static final String RELEASE = "RELEASE";
    public static final String NSIDE = "NSIDE";
    public static final String START_DATE = "START_DATE";
    public static final String END_DATE = "END_DATE";
    public static final String DETECTORS = "DETECTORS";
    public static final String TOIS = "TOIS";

    // Important!!! There are problems using enums from another gwt module (this must be more deeply
    // analyzed)
    public static final String PRODUCT_TYPE_REP_MAP_ALL = "REP_MAP_ALL";
    public static final String PRODUCT_TYPE_REP_MAP = "REP_MAP";
    public static final String PRODUCT_TYPE_REP_BEAM_ALL = "REP_BEAM_ALL";
    public static final String PRODUCT_TYPE_REP_BEAM = "REP_BEAM";
    public static final String PRODUCT_TYPE_BEAM = "BEAM";
    public static final String PRODUCT_TYPE_REP_MAP_AND_BEAM = "REP_MAP_AND_BEAM";
    public static final String PRODUCT_TYPE_DOCUMENT_SOURCE_LIST = "DOCUMENT_SOURCE_LIST";
    public static final String PRODUCT_TYPE_SCANNING_BEAM = "SCANNING_BEAM";

    public static final String PRODUCT_TYPE_DOCUMENT_MAP = "DOCUMENT_MAP";
    public static final String PRODUCT_TYPE_MAP = "MAP";
    public static final String PRODUCT_TYPE_MAP_ALL = "MAP_ALL";

    /**
     * Defines the possible types of retrieval in the Data Distribution: product or postcard.
     */
    public enum RetrievalType {
        PRODUCT(PRODUCT_RETRIEVAL_TYPE), POSTCARD(POSTCARD_RETRIEVAL_TYPE);

        private final String symbol;

        RetrievalType(String symbol) {
            this.symbol = symbol;
        }

        @Override
        public String toString() {
            return symbol;
        }

        public String getKey() {
            return PlaRetrievalConstants.RETRIEVAL_TYPE_KEY;
        }
    }

    // List of product types in PLA
    public static enum PlaProductType {
        // Map
        MAP("Map"), MAP_DOCUMENT("Document"), FREQUENCY_MAP("Sky map"), CMB_MAP("CMB map"), COMPONENT_MAP(
                "Component map"), MASK_MAP("Mask"), DATES_OBS_MAP("DatesObs map"), CORR_MAP(
                "Correction map"), MAP_ALL("All"), SIMULATED_MAP("Simulated map"),

        // Map re-projection
        REP_MAP("Re-projected Map"), REP_MAP_PREV_IMG("Preview Image"), REP_MAP_ALL("All"), REP_MAP_AND_BEAM(
                "Re-projected map and beam"),
        // Effective beams
        BEAM("Effective beams"), REP_BEAM("Re-projected cutout beam"), REP_BEAM_PREV_IMG(
                "Preview image of the cutout beam"), REP_BEAM_ALL(
                "Re-reprojected beam cutout and preview image"),

        // Scanning beam
        SCANNING_BEAM("Scanning beams"),

        // Source Lists
        SOURCE_LIST("SourceList"), SOURCE_LIST_DOCUMENT("Document"), SOURCE_LIST_ALL("All"),
        // Operational files
        OP_FILE("Operational File"),
        // Generic Files
        GENERIC_FILE("File"),
        // Software
        SW_FILE("File"),
        // Cosmology
        COSMO("File"), COSMO_DOCUMENT("Document"), COSMO_ALL("All"),
        // Ancillary data
        ANC_DATA("Ancillary Data"),
        // Posh
        POSH("Posh"), POSH_CATALOG("Catalogue"), POSH_DOCUMENT("Documents"), POSH_ALL("All"),
        // Source
        SOURCE("Source"),
        // Documents
        DOCUMENT_COSMOLOGY("Cosmology document"), DOCUMENT_MAP("Map document"), DOCUMENT_SOURCE_LIST(
                "Source list document"),
        // Postcard
        POSTCARD_MAP("Map postcard"), POSTCARD_SOURCE("Source postcard"),

        // Timelines
        TOI("Timeline"), TOI_SCI("Sci timeline"), TOI_PTG("Pointing timeline"), TOI_SCI_AND_PTG(
                "Sci and associated pointing timelines"), TOI_HK("House keeping timeline"), TOI_OFF(
                "Offset timeline"), TOI_TAI("TAI timeline"), TOI_CUTTING("Toi cutting");

        // Label to be shown in the UI
        private String label;

        /**
         * Default Constructor
         * 
         * @param label
         */
        private PlaProductType(String label) {
            this.label = label;
        }

        @Override
        public String toString() {
            return label;
        }
    }

}
